@@ -1,23 +1,25 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+# -*- coding: future_fstrings -*-
 
 import sys
 import getpass
 import shutil
 import os
-from db_sync_tool.utility import mode, connect, system, output
+from db_sync_tool.utility import mode, system, output
+from db_sync_tool.remote import utility as remote_utility
 
 #
 # FUNCTIONS
 #
 
+
 def clean_up():
     """
     Clean up
     :return:
     """
     if not mode.is_import():
-        connect.remove_target_database_dump()
+        remote_utility.remove_target_database_dump()
         if mode.get_sync_mode() == mode.SyncMode.PROXY:
             remove_temporary_data_dir()
 
@@ -92,9 +94,9 @@ def get_command(client, command):
     :param command:
     :return: String command
     """
-    if 'console' in system.config['host'][client]:
-        if command in system.config['host'][client]['console']:
-            return system.config['host'][client]['console'][command]
+    if 'console' in system.config[client]:
+        if command in system.config[client]['console']:
+            return system.config[client]['console'][command]
     return command
 
 
@@ -104,13 +106,10 @@ def get_dump_dir(client):
     :param client:
     :return: String path
     """
-    if system.option[f'default_{client}_dump_dir']:
-        if not mode.is_remote(client):
-            return '/home/' + getpass.getuser() + '/'
-        else:
-            return '/home/' + system.config['host'][client]['user'] + '/'
+    if system.config[f'default_{client}_dump_dir']:
+        return '/tmp/'
     else:
-        return system.config['host'][client]['dump_dir']
+        return system.config[client]['dump_dir']
 
 
 def check_and_create_dump_dir(client, path):
@@ -134,12 +133,12 @@ def get_ssh_host_name(client, with_user=False):
     :return:
     """
     if with_user:
-        _host = system.config['host'][client]['user'] + '@' + system.config['host'][client]['host']
+        _host = system.config[client]['user'] + '@' + system.config[client]['host']
     else:
-        _host = system.config['host'][client]['host']
+        _host = system.config[client]['host']
 
-    if 'name' in system.config['host'][client]:
-        return output.CliFormat.BOLD + system.config['host'][client][
+    if 'name' in system.config[client]:
+        return output.CliFormat.BOLD + system.config[client][
             'name'] + output.CliFormat.ENDC + output.CliFormat.BLACK + ' (' + _host + ')' + output.CliFormat.ENDC
     else:
         return _host
@@ -172,3 +171,54 @@ def dict_to_args(dict):
     if len(_args) == 0:
         return None
     return _args
+
+
+def check_file_exists(client, path):
+    """
+    Check if a file exists
+    :param client: String
+    :param path: String file path
+    :return: Boolean
+    """
+    return mode.run_command(f'[ -f {path} ] && echo "1"', client, True) == '1'
+
+
+def confirm(prompt=None, resp=False):
+    """
+    https://code.activestate.com/recipes/541096-prompt-the-user-for-confirmation/
+
+    prompts for yes or no response from the user. Returns True for yes and
+    False for no.
+
+    'resp' should be set to the default value assumed by the caller when
+    user simply types ENTER.
+
+    >>> confirm(prompt='Create Directory?', resp=True)
+    Create Directory? [Y|n]:
+    True
+    >>> confirm(prompt='Create Directory?', resp=False)
+    Create Directory? [y|N]:
+    False
+
+    """
+
+    if prompt is None:
+        prompt = 'Confirm'
+
+    if resp:
+        prompt = '%s [%s|%s]: ' % (prompt, 'Y', 'n')
+    else:
+        prompt = '%s [%s|%s]: ' % (prompt, 'y', 'N')
+
+    while True:
+        ans = input(prompt)
+        if not ans:
+            return resp
+        if ans not in ['y', 'Y', 'n', 'N']:
+            print
+            'please enter y or n.'
+            continue
+        if ans == 'y' or ans == 'Y':
+            return True
+        if ans == 'n' or ans == 'N':
+            return False
